@@ -9,6 +9,8 @@
 
 #include "mapcsstypes.h"
 
+#include <osm/element.h>
+
 #include <memory>
 #include <vector>
 
@@ -22,6 +24,9 @@ public:
     OSM::StringKeyRegistry<ClassSelectorKey> m_classSelectorRegistry;
     OSM::StringKeyRegistry<LayerSelectorKey> m_layerSelectorRegistry;
 
+    OSM::TagKey m_areaKey;
+    OSM::TagKey m_typeKey;
+
     inline static MapCSSStylePrivate* get(MapCSSStyle *style) { return style->d.get(); }
 };
 
